@@ -5,20 +5,21 @@ help make new Ops more rapidly.
 
 """
 
-from collections import OrderedDict
-
 import copy
-import six.moves.cPickle as pickle
 import warnings
 
-import theano
-from theano import gof
-from six import iteritems, integer_types
-from six.moves import xrange
-
+import six.moves.cPickle as pickle
 
 import numpy as np
 
+import theano
+
+from collections import OrderedDict
+
+from six import integer_types
+
+from theano.gof import Op, Apply, ParamsType, Variable
+
 
 def register_view_op_c_code(type, code, version=()):
     """
@@ -38,7 +39,7 @@ def register_view_op_c_code(type, code, version=()):
     ViewOp.c_code_and_version[type] = (code, version)
 
 
-class ViewOp(gof.Op):
+class ViewOp(Op):
     """
     Returns an inplace view of the input. Used internally by Theano.
 
@@ -53,7 +54,7 @@ class ViewOp(gof.Op):
     _f16_ok = True
 
     def make_node(self, x):
-        return gof.Apply(self, [x], [x.type()])
+        return Apply(self, [x], [x.type()])
 
     def perform(self, node, inp, out):
         (x,) = inp
@@ -81,7 +82,7 @@ class ViewOp(gof.Op):
         # If any of the c code is unversionned, we have to return ()
         # Else, we will return a list of (type name, version) pairs.
         for t, (c, v) in sorted(
-            iteritems(self.c_code_and_version), key=lambda pair: str(pair[0])
+            self.c_code_and_version.items(), key=lambda pair: str(pair[0])
         ):
             if not v:
                 warnings.warn(
@@ -150,7 +151,7 @@ def register_deep_copy_op_c_code(typ, code, version=()):
     DeepCopyOp.c_code_and_version[typ] = (code, version)
 
 
-class DeepCopyOp(gof.Op):
+class DeepCopyOp(Op):
     # Mapping from Type to C code (and version) to use.
     # In the C code, the name of the input variable is %(iname)s,
     # the output variable is %(oname)s.
@@ -164,7 +165,7 @@ class DeepCopyOp(gof.Op):
         pass
 
     def make_node(self, x):
-        return gof.Apply(self, [x], [x.type()])
+        return Apply(self, [x], [x.type()])
 
     def perform(self, node, args, outs):
         if hasattr(args[0], "copy"):
@@ -181,7 +182,7 @@ class DeepCopyOp(gof.Op):
         # If any of the c code is unversionned, we have to return ()
         # Else, we will return a list of (type name, version) pairs.
         for t, (c, v) in sorted(
-            iteritems(self.c_code_and_version), key=lambda pair: str(pair[0])
+            self.c_code_and_version.items(), key=lambda pair: str(pair[0])
         ):
             if not v:
                 warnings.warn(
@@ -234,7 +235,7 @@ def register_shape_c_code(type, code, version=()):
     Shape.c_code_and_version[type] = (code, version)
 
 
-class Shape(gof.Op):
+class Shape(Op):
     """
     L{Op} to return the shape of a matrix.
 
@@ -259,7 +260,7 @@ class Shape(gof.Op):
         # This will fail at execution time.
         if not isinstance(x, theano.Variable):
             x = theano.tensor.as_tensor_variable(x)
-        return gof.Apply(self, [x], [theano.tensor.lvector()])
+        return Apply(self, [x], [theano.tensor.lvector()])
 
     def perform(self, node, inp, out_):
         (x,) = inp
@@ -306,7 +307,7 @@ class Shape(gof.Op):
         # If any of the c code is unversionned, we have to return ()
         # Else, we will return a list of (type name, version) pairs.
         for t, (c, v) in sorted(
-            iteritems(self.c_code_and_version), key=lambda pair: str(pair[0])
+            self.c_code_and_version.items(), key=lambda pair: str(pair[0])
         ):
             if not v:
                 warnings.warn(
@@ -328,7 +329,7 @@ shape = Shape()
 _shape = shape  # was used in the past, now use shape directly.
 
 
-class Shape_i(gof.Op):
+class Shape_i(Op):
     """
     L{Op} to return the shape of a matrix.
 
@@ -368,7 +369,7 @@ class Shape_i(gof.Op):
     #    using params.
     @property
     def params_type(self):
-        return gof.ParamsType(i=theano.scalar.basic.int64)
+        return ParamsType(i=theano.scalar.basic.int64)
 
     def __str__(self):
         return "%s{%i}" % (self.__class__.__name__, self.i)
@@ -396,7 +397,7 @@ class Shape_i(gof.Op):
         # If any of the c code is unversionned, we have to return ()
         # Else, we will return a list of (type name, version) pairs.
         for t, (c, ci, v) in sorted(
-            iteritems(self.c_code_and_version), key=lambda pair: str(pair[0])
+            self.c_code_and_version.items(), key=lambda pair: str(pair[0])
         ):
             if not v:
                 warnings.warn(
@@ -539,7 +540,7 @@ def load_back(mod, name):
     return obj
 
 
-class FromFunctionOp(gof.Op):
+class FromFunctionOp(Op):
     """
     Build a basic Theano Op around a function.
 
@@ -665,7 +666,7 @@ def register_rebroadcast_c_code(typ, code, version=()):
     Rebroadcast.c_code_and_version[typ] = (code, version)
 
 
-class Rebroadcast(gof.Op):
+class Rebroadcast(Op):
     """
     Change the input's broadcastable fields in some predetermined way.
 
@@ -679,8 +680,8 @@ class Rebroadcast(gof.Op):
     -----
     Works inplace and works for CudaNdarrayType.
 
-    Example
-    -------
+    Examples
+    --------
     `Rebroadcast((0, True), (1, False))(x)` would make `x` broadcastable in
     axis 0 and not broadcastable in axis 1.
 
@@ -701,7 +702,7 @@ class Rebroadcast(gof.Op):
         # Sort them to make sure we merge all possible case.
         items = sorted(axis)
         self.axis = OrderedDict(items)
-        for axis, broad in iteritems(self.axis):
+        for axis, broad in self.axis.items():
             if not isinstance(axis, (np.integer, integer_types)):
                 raise TypeError(
                     "Rebroadcast needs integer axes. " "Got {}".format(axis)
@@ -716,15 +717,15 @@ class Rebroadcast(gof.Op):
     def __hash__(self):
         # Need special __hash__ as dict aren't hashable.
         # no ambiguity because each item key is unique
-        items = sorted(iteritems(self.axis))
+        items = sorted(self.axis.items())
         return hash((type(self), tuple(items)))
 
     def __str__(self):
         if len(self.axis) == 0:
             broadcast_pattern = []
         else:
-            broadcast_pattern = ["?" for i in xrange(1 + max(self.axis.keys()))]
-        for k, v in iteritems(self.axis):
+            broadcast_pattern = ["?" for i in range(1 + max(self.axis.keys()))]
+        for k, v in self.axis.items():
             broadcast_pattern[k] = str(int(v))
         return "%s{%s}" % (self.__class__.__name__, ",".join(broadcast_pattern))
 
@@ -736,12 +737,12 @@ class Rebroadcast(gof.Op):
                 self.axis.get(i, b) for i, b in enumerate(x.type.broadcastable)
             ]
         )
-        return gof.Apply(self, [x], [t()])
+        return Apply(self, [x], [t()])
 
     def perform(self, node, inp, out_):
         (x,) = inp
         (out,) = out_
-        for axis, value in iteritems(self.axis):
+        for axis, value in self.axis.items():
             if value and x.shape[axis] != 1:
                 raise ValueError(
                     "Dimension %s in Rebroadcast's input was"
@@ -757,7 +758,7 @@ class Rebroadcast(gof.Op):
             Rebroadcast(
                 *[
                     (axis, x.type.broadcastable[axis])
-                    for axis, value in iteritems(self.axis)
+                    for axis, value in self.axis.items()
                 ]
             )(gz),
         )
@@ -766,7 +767,7 @@ class Rebroadcast(gof.Op):
         assert len(ishapes) == 1
         l = []
         one = theano.tensor.basic.constant(1)
-        for ax in xrange(len(ishapes[0])):
+        for ax in range(len(ishapes[0])):
             if self.axis.get(ax, False):
                 l.append(one)
             else:
@@ -788,7 +789,7 @@ class Rebroadcast(gof.Op):
         if itype in self.c_code_and_version:
             code, version = self.c_code_and_version[itype]
             final_code = ""
-            for axis, value in iteritems(self.axis):
+            for axis, value in self.axis.items():
                 if value:
                     final_code += code % locals()
             return (
@@ -807,7 +808,7 @@ class Rebroadcast(gof.Op):
         # If any of the c code is unversionned, we have to return ()
         # Else, we will return a list of (type name, version) pairs.
         for t, (c, v) in sorted(
-            iteritems(self.c_code_and_version), key=lambda pair: str(pair[0])
+            self.c_code_and_version.items(), key=lambda pair: str(pair[0])
         ):
             if not v:
                 warnings.warn(
@@ -847,7 +848,7 @@ def register_specify_shape_c_code(typ, code, version=(), c_support_code_apply=No
     SpecifyShape.c_code_and_version[typ] = (code, version, c_support_code_apply)
 
 
-class SpecifyShape(gof.Op):
+class SpecifyShape(Op):
     """
     L{Op} that puts into the graph the user-provided shape.
 
@@ -875,14 +876,14 @@ class SpecifyShape(gof.Op):
     _f16_ok = True
 
     def make_node(self, x, shape):
-        if not isinstance(x, gof.Variable):
+        if not isinstance(x, Variable):
             x = theano.tensor.as_tensor_variable(x)
         shape = theano.tensor.as_tensor_variable(shape)
         assert shape.ndim == 1
         assert shape.dtype in theano.tensor.integer_dtypes
         if isinstance(shape, theano.tensor.TensorConstant):
             assert shape.data.size == x.ndim
-        return gof.Apply(self, [x, shape], [x.type()])
+        return Apply(self, [x, shape], [x.type()])
 
     def perform(self, node, inp, out_):
         x, shape = inp
@@ -894,7 +895,7 @@ class SpecifyShape(gof.Op):
     def infer_shape(self, node, shapes):
         xshape, sshape = shapes
         new_shape = []
-        for dim in xrange(node.inputs[0].ndim):
+        for dim in range(node.inputs[0].ndim):
             try:
                 s = theano.tensor.get_scalar_constant_value(node.inputs[1][dim])
                 s = theano.tensor.as_tensor_variable(s)
@@ -951,7 +952,7 @@ class SpecifyShape(gof.Op):
         # If any of the c code is unversionned, we have to return ()
         # Else, we will return a list of (type name, version) pairs.
         for t, (c, v, _) in sorted(
-            iteritems(self.c_code_and_version), key=lambda pair: str(pair[0])
+            self.c_code_and_version.items(), key=lambda pair: str(pair[0])
         ):
             if not v:
                 warnings.warn(
