@@ -2,10 +2,6 @@
 Defines Linkers that deal with C implementations.
 
 """
-
-
-# Python imports
-from copy import copy
 import os
 import sys
 import logging
@@ -13,17 +9,16 @@ import logging
 import numpy as np
 
 import theano
+
+from copy import copy
+
+from six import string_types, reraise
+from six.moves import StringIO
+
 from theano import config
 from theano.compat import PY3
-from theano.compat import izip
-from six import string_types, reraise
-from six.moves import StringIO, xrange
 
-# gof imports
-from theano.gof import graph
-from theano.gof import link
-from theano.gof import utils
-from theano.gof import cmodule
+from theano.gof import graph, link, utils, cmodule
 from theano.gof.compilelock import get_lock, release_lock
 from theano.gof.callcache import CallCache
 
@@ -1223,11 +1218,11 @@ class CLinker(link.Linker):
             module,
             [
                 link.Container(input, storage)
-                for input, storage in izip(self.fgraph.inputs, input_storage)
+                for input, storage in zip(self.fgraph.inputs, input_storage)
             ],
             [
                 link.Container(output, storage, True)
-                for output, storage in izip(self.fgraph.outputs, output_storage)
+                for output, storage in zip(self.fgraph.outputs, output_storage)
             ],
             error_storage,
         )
@@ -1772,7 +1767,7 @@ class CLinker(link.Linker):
         )
         print(
             "  if (struct_ptr->init(",
-            ",".join("PyTuple_GET_ITEM(argtuple, %i)" % n for n in xrange(n_args)),
+            ",".join("PyTuple_GET_ITEM(argtuple, %i)" % n for n in range(n_args)),
             ") != 0) {",
             file=code,
         )
@@ -2013,11 +2008,11 @@ class OpWiseCLinker(link.LocalLinker):
             f,
             [
                 link.Container(input, storage)
-                for input, storage in izip(fgraph.inputs, input_storage)
+                for input, storage in zip(fgraph.inputs, input_storage)
             ],
             [
                 link.Container(output, storage, True)
-                for output, storage in izip(fgraph.outputs, output_storage)
+                for output, storage in zip(fgraph.outputs, output_storage)
             ],
             thunks,
             order,
@@ -2116,22 +2111,22 @@ class DualLinker(link.Linker):
         )
 
         def f():
-            for input1, input2 in izip(i1, i2):
+            for input1, input2 in zip(i1, i2):
                 # Set the inputs to be the same in both branches.
                 # The copy is necessary in order for inplace ops not to
                 # interfere.
                 input2.storage[0] = copy(input1.storage[0])
-            for thunk1, thunk2, node1, node2 in izip(thunks1, thunks2, order1, order2):
-                for output, storage in izip(node1.outputs, thunk1.outputs):
+            for thunk1, thunk2, node1, node2 in zip(thunks1, thunks2, order1, order2):
+                for output, storage in zip(node1.outputs, thunk1.outputs):
                     if output in no_recycling:
                         storage[0] = None
-                for output, storage in izip(node2.outputs, thunk2.outputs):
+                for output, storage in zip(node2.outputs, thunk2.outputs):
                     if output in no_recycling:
                         storage[0] = None
                 try:
                     thunk1()
                     thunk2()
-                    for output1, output2 in izip(thunk1.outputs, thunk2.outputs):
+                    for output1, output2 in zip(thunk1.outputs, thunk2.outputs):
                         self.checker(output1, output2)
                 except Exception:
                     link.raise_with_op(node1)
