@@ -21,17 +21,17 @@ __contact__ = "Razvan Pascanu <r.pascanu@gmail>"
 import copy
 import logging
 import warnings
-from collections import OrderedDict
 
 import numpy as np
 
 import theano
-from theano.compat import izip
-from six import string_types, iteritems
-from six.moves import xrange
+
+from collections import OrderedDict
+
+from six import string_types
+
+from theano import gof, compat, tensor, scalar
 from theano.compile.pfunc import rebuild_collect_shared
-from theano import gof, compat
-from theano import tensor, scalar
 from theano.tensor.basic import get_scalar_constant_value
 
 
@@ -173,7 +173,7 @@ def traverse(out, x, x_copy, d, visited=None):
 def hash_listsDictsTuples(x):
     hash_value = 0
     if isinstance(x, dict):
-        for k, v in iteritems(x):
+        for k, v in x.items():
             hash_value ^= hash_listsDictsTuples(k)
             hash_value ^= hash_listsDictsTuples(v)
     elif isinstance(x, (list, tuple)):
@@ -525,7 +525,7 @@ def get_updates_and_outputs(ls):
         if isinstance(x, list) or isinstance(x, tuple):
             iter_on = x
         elif isinstance(x, dict):
-            iter_on = iteritems(x)
+            iter_on = x.items()
         if iter_on is not None:
             return all(_filter(y) for y in iter_on)
         else:
@@ -626,7 +626,7 @@ def expand_empty(tensor_var, size):
 
     if size == 0:
         return tensor_var
-    shapes = [tensor_var.shape[x] for x in xrange(tensor_var.ndim)]
+    shapes = [tensor_var.shape[x] for x in range(tensor_var.ndim)]
     new_shape = [size + shapes[0]] + shapes[1:]
     empty = tensor.AllocEmpty(tensor_var.dtype)(*new_shape)
 
@@ -635,143 +635,6 @@ def expand_empty(tensor_var, size):
     return ret
 
 
-def equal_computations(xs, ys, in_xs=None, in_ys=None):
-    """Checks if Theano graphs represent the same computations.
-
-    The two lists `xs`, `ys` should have the same number of entries. The
-    function checks if for any corresponding pair `(x,y)` from `zip(xs,ys)`
-    `x` and `y` represent the same computations on the same variables
-    (unless equivalences are provided using `in_xs`, `in_ys`).
-
-    If `in_xs` and `in_ys` are provided, then when comparing a node `x` with
-    a node `y` they are automatically considered as equal if there is some
-    index `i` such that `x == in_xs[i]` and `y == in_ys[i]`(and they both
-    have the same type). Note that `x` and `y` can be in the list `xs` and
-    `ys`, but also represent subgraphs of a computational graph in `xs`
-    or `ys`.
-
-    """
-    assert len(xs) == len(ys)
-    if in_xs is None:
-        in_xs = []
-    if in_ys is None:
-        in_ys = []
-
-    for x, y in izip(xs, ys):
-        if x.owner and not y.owner:
-            return False
-        if y.owner and not x.owner:
-            return False
-        if x.owner:  # Check above tell that y.owner eval to True too.
-            if x.owner.outputs.index(x) != y.owner.outputs.index(y):
-                return False
-        if x not in in_xs and x.type != y.type:
-            return False
-    if len(in_xs) != len(in_ys):
-        return False
-    for _x, _y in izip(in_xs, in_ys):
-        if _x.type != _y.type:
-            return False
-
-    common = set(zip(in_xs, in_ys))
-    different = set()
-    for dx, dy in izip(xs, ys):
-        # We checked above that both dx and dy have an owner or not
-        if not dx.owner:
-            if isinstance(dx, tensor.Constant) and isinstance(dy, tensor.Constant):
-                if not dx.equals(dy):
-                    return False
-                else:
-                    pass
-            elif (dx, dy) not in common and dx != dy:
-                return False
-
-    # Explore the two graphs, in parallel, depth first, comparing the nodes
-    # along the way for equality.
-    def compare_nodes(nd_x, nd_y, common, different):
-        """
-        Compare two nodes to determine if they perform equal computation.
-        This is done by comparing the ops, the number of inputs, outputs and
-        by ensuring that the inputs themselves are the result of equal
-        computation.
-
-        NOTE : This function relies on the variable common to cache
-        results to be more efficient.
-
-        """
-
-        if nd_x.op != nd_y.op:
-            return False
-        elif len(nd_x.inputs) != len(nd_y.inputs):
-            return False
-        elif len(nd_x.outputs) != len(nd_y.outputs):
-            return False
-        else:
-            all_in_common = True
-            for dx, dy in izip(nd_x.outputs, nd_y.outputs):
-                if (dx, dy) in different:
-                    return False
-                if (dx, dy) not in common:
-                    all_in_common = False
-
-            if all_in_common:
-                return True
-
-            # Compare the individual inputs for equality
-            for dx, dy in izip(nd_x.inputs, nd_y.inputs):
-                if (dx, dy) not in common:
-
-                    # Equality between the variables is unknown, compare
-                    # their respective owners, if they have some
-                    if (
-                        dx.owner
-                        and dy.owner
-                        and dx.owner.outputs.index(dx) == dy.owner.outputs.index(dy)
-                    ):
-
-                        nodes_equal = compare_nodes(
-                            dx.owner, dy.owner, common, different
-                        )
-                        if not nodes_equal:
-                            different.add((dx, dy))
-                            return False
-
-                    # If both variables don't have an owner, then they are
-                    # inputs and can be directly compared
-                    elif dx.owner is None and dy.owner is None:
-
-                        if dx != dy:
-                            if isinstance(dx, tensor.Constant) and isinstance(
-                                dy, tensor.Constant
-                            ):
-                                if not dx.equals(dy):
-                                    return False
-                            else:
-                                return False
-
-                    else:
-                        return False
-
-            # If the code reaches this statement then the inputs are pair-wise
-            # equivalent so the outputs of the current nodes are also
-            # pair-wise equivalents
-            for dx, dy in izip(nd_x.outputs, nd_y.outputs):
-                common.add((dx, dy))
-
-            return True
-
-    # Validate that each xs[i], ys[i] pair represents the same computation
-    for i in range(len(xs)):
-        if xs[i].owner:
-            # The case where pairs of x[i]s and y[i]s don't both have an owner
-            # have already been addressed.
-            is_equal = compare_nodes(xs[i].owner, ys[i].owner, common, different)
-            if not is_equal:
-                return False
-
-    return True
-
-
 def infer_shape(outs, inputs, input_shapes):
     """
     Compute the shape of the outputs given the shape of the inputs of a theano
@@ -785,7 +648,7 @@ def infer_shape(outs, inputs, input_shapes):
     # inside.  We don't use the full ShapeFeature interface, but we
     # let it initialize itself with an empty fgraph, otherwise we will
     # need to do it manually
-    for inp, inp_shp in izip(inputs, input_shapes):
+    for inp, inp_shp in zip(inputs, input_shapes):
         if inp_shp is not None and len(inp_shp) != inp.ndim:
             assert len(inp_shp) == inp.ndim
 
@@ -793,7 +656,7 @@ def infer_shape(outs, inputs, input_shapes):
     shape_feature.on_attach(theano.gof.FunctionGraph([], []))
 
     # Initialize shape_of with the input shapes
-    for inp, inp_shp in izip(inputs, input_shapes):
+    for inp, inp_shp in zip(inputs, input_shapes):
         shape_feature.set_shape(inp, inp_shp)
 
     def local_traverse(out):
@@ -959,8 +822,8 @@ def scan_can_remove_outs(op, out_idxs):
         n_ins = len(op.info["tap_array"][idx])
         out_ins += [op.inputs[offset : offset + n_ins]]
         offset += n_ins
-    out_ins += [[] for k in xrange(op.n_nit_sot)]
-    out_ins += [[op.inputs[offset + k]] for k in xrange(op.n_shared_outs)]
+    out_ins += [[] for k in range(op.n_nit_sot)]
+    out_ins += [[op.inputs[offset + k]] for k in range(op.n_shared_outs)]
 
     added = True
     out_idxs_mask = [1 for idx in out_idxs]
@@ -1017,7 +880,7 @@ def compress_outs(op, not_required, inputs):
     i_offset = op.n_seqs
     o_offset = 0
     curr_pos = 0
-    for idx in xrange(op.info["n_mit_mot"]):
+    for idx in range(op.info["n_mit_mot"]):
         if offset + idx not in not_required:
             map_old_new[offset + idx] = curr_pos
             curr_pos += 1
@@ -1041,7 +904,7 @@ def compress_outs(op, not_required, inputs):
     offset += op.n_mit_mot
     ni_offset += op.n_mit_mot
 
-    for idx in xrange(op.info["n_mit_sot"]):
+    for idx in range(op.info["n_mit_sot"]):
         if offset + idx not in not_required:
             map_old_new[offset + idx] = curr_pos
             curr_pos += 1
@@ -1062,7 +925,7 @@ def compress_outs(op, not_required, inputs):
 
     offset += op.n_mit_sot
     ni_offset += op.n_mit_sot
-    for idx in xrange(op.info["n_sit_sot"]):
+    for idx in range(op.info["n_sit_sot"]):
         if offset + idx not in not_required:
             map_old_new[offset + idx] = curr_pos
             curr_pos += 1
@@ -1083,7 +946,7 @@ def compress_outs(op, not_required, inputs):
     offset += op.n_sit_sot
     ni_offset += op.n_sit_sot
     nit_sot_ins = []
-    for idx in xrange(op.info["n_nit_sot"]):
+    for idx in range(op.info["n_nit_sot"]):
         if offset + idx not in not_required:
             map_old_new[offset + idx] = curr_pos
             curr_pos += 1
@@ -1096,7 +959,7 @@ def compress_outs(op, not_required, inputs):
 
     offset += op.n_nit_sot
     shared_ins = []
-    for idx in xrange(op.info["n_shared_outs"]):
+    for idx in range(op.info["n_shared_outs"]):
         if offset + idx not in not_required:
             map_old_new[offset + idx] = curr_pos
             curr_pos += 1
@@ -1134,7 +997,7 @@ def reconstruct_graph(inputs, outputs, tag=None):
         tag = ""
     nw_inputs = [safe_new(x, tag) for x in inputs]
     givens = OrderedDict()
-    for nw_x, x in izip(nw_inputs, inputs):
+    for nw_x, x in zip(nw_inputs, inputs):
         givens[x] = nw_x
     allinputs = theano.gof.graph.inputs(outputs)
     for inp in allinputs:
@@ -1393,8 +1256,8 @@ def forced_replace(out, x, y):
     x := sigmoid(wu)
     forced_replace(out, x, y) := y*(1-y)
 
-    Note
-    ----
+    Notes
+    -----
     When it find a match, it don't continue on the corresponding inputs.
     """
     if out is None:
@@ -1413,7 +1276,7 @@ def forced_replace(out, x, y):
         if graph in visited:
             continue
         visited.add(graph)
-        if equal_computations([graph], [x]):
+        if gof.graph.equal_computations([graph], [x]):
             to_replace.append((graph, y))
         elif graph.owner:
             q.extendleft(graph.owner.inputs)
