@@ -1,12 +1,13 @@
 from copy import copy
 
 import numpy as np
-from six import iteritems, integer_types
-from six.moves import xrange
 
 import theano
+
+from six import integer_types
+
 from theano import gof
-from theano.compat import izip
+
 from theano import change_flags
 from theano.gof import Apply, Op, COp, OpenMPOp, ParamsType
 from theano import scalar
@@ -79,8 +80,8 @@ class DimShuffle(COp):
     inplace : bool, optional
         If True (default), the output will be a view of the input.
 
-    Note
-    ----
+    Notes
+    -----
     If `j = new_order[i]` is an index, the output's ith dimension
     will be the input's jth dimension.
     If `new_order[i]` is `x`, the output's ith dimension will
@@ -90,8 +91,6 @@ class DimShuffle(COp):
     If `input.broadcastable[i] == False` then `i` must be found in new_order.
     Broadcastable dimensions, on the other hand, can be discarded.
 
-    Note
-    ----
     .. code-block:: python
 
         DimShuffle((False, False, False), ['x', 2, 'x', 0, 1])
@@ -114,8 +113,8 @@ class DimShuffle(COp):
     If the tensor has shape (1, 20), the resulting tensor will have shape
     (20, ).
 
-    Example
-    -------
+    Examples
+    --------
     .. code-block:: python
 
         DimShuffle((), ['x'])  # make a 0d (scalar) into a 1d vector
@@ -398,8 +397,8 @@ class Elemwise(OpenMPOp):
         variable number of inputs), whereas the numpy function may
         not have varargs.
 
-    Note
-    ----
+    Notes
+    -----
     | Elemwise(add) represents + on tensors (x + y)
     | Elemwise(add, {0 : 0}) represents the += operation (x += y)
     | Elemwise(add, {0 : 1}) represents += on the second argument (y += x)
@@ -481,15 +480,15 @@ second dimension
         out_broadcastables = [
             [
                 all(bcast)
-                for bcast in izip(*[input.type.broadcastable for input in inputs])
+                for bcast in zip(*[input.type.broadcastable for input in inputs])
             ]
         ] * shadow.nout
 
         # inplace_pattern maps output idx -> input idx
         inplace_pattern = self.inplace_pattern
         if inplace_pattern:
-            for overwriter, overwritten in iteritems(inplace_pattern):
-                for ob, ib in izip(
+            for overwriter, overwritten in inplace_pattern.items():
+                for ob, ib in zip(
                     out_broadcastables[overwriter],
                     inputs[overwritten].type.broadcastable,
                 ):
@@ -524,7 +523,7 @@ second dimension
         )
         outputs = [
             TensorType(dtype=dtype, broadcastable=broadcastable)()
-            for dtype, broadcastable in izip(out_dtypes, out_broadcastables)
+            for dtype, broadcastable in zip(out_dtypes, out_broadcastables)
         ]
         return Apply(self, inputs, outputs)
 
@@ -552,7 +551,7 @@ second dimension
             bgrads = self._bgrad(inputs, outs, ograds)
             rop_out = None
 
-            for jdx, (inp, eval_point) in enumerate(izip(inputs, eval_points)):
+            for jdx, (inp, eval_point) in enumerate(zip(inputs, eval_points)):
                 # if None, then we can just ignore this branch ..
                 # what we do is to assume that for any non-differentiable
                 # branch, the gradient is actually 0, which I think is not
@@ -599,7 +598,7 @@ second dimension
             # can tell this op did
             # the right thing.
             new_rval = []
-            for elem, ipt in izip(rval, inputs):
+            for elem, ipt in zip(rval, inputs):
                 if isinstance(elem.type, (NullType, DisconnectedType)):
                     new_rval.append(elem)
                 else:
@@ -683,7 +682,7 @@ second dimension
             return new_r
 
         ret = []
-        for scalar_igrad, ipt in izip(scalar_igrads, inputs):
+        for scalar_igrad, ipt in zip(scalar_igrads, inputs):
             if scalar_igrad is None:
                 # undefined gradient
                 ret.append(None)
@@ -773,7 +772,7 @@ second dimension
             # should be disabled.
             super(Elemwise, self).perform(node, inputs, output_storage)
 
-        for dims in izip(
+        for dims in zip(
             *[
                 list(zip(input.shape, sinput.type.broadcastable))
                 for input, sinput in zip(inputs, node.inputs)
@@ -800,7 +799,7 @@ second dimension
 
         # Determine the shape of outputs
         out_shape = []
-        for values in izip(*[input.shape for input in inputs]):
+        for values in zip(*[input.shape for input in inputs]):
             if any(v == 0 for v in values):
                 # All non-broadcasted dimensions should be zero
                 assert max(values) <= 1
@@ -851,7 +850,7 @@ second dimension
         if nout == 1:
             variables = [variables]
         i = 0
-        for variable, storage, nout in izip(variables, output_storage, node.outputs):
+        for variable, storage, nout in zip(variables, output_storage, node.outputs):
             if getattr(variable, "dtype", "") == "object":
                 # Since numpy 1.6, function created with numpy.frompyfunc
                 # always return an ndarray with dtype object
@@ -893,7 +892,7 @@ second dimension
                 else:
                     # there must be some input that is not broadcastable in
                     # dimension 'dim'
-                    for ishp, i in izip(i_shapes, node.inputs):
+                    for ishp, i in zip(i_shapes, node.inputs):
                         if isinstance(i.type, theano.scalar.Scalar):
                             continue  # we skip scalar
                         if not i.type.broadcastable[dim]:
@@ -941,7 +940,7 @@ second dimension
         dmap = dict(
             [
                 (node.outputs[o], [node.inputs[i]])
-                for o, i in iteritems(self.inplace_pattern)
+                for o, i in self.inplace_pattern.items()
             ]
         )
 
@@ -954,7 +953,7 @@ second dimension
             zip(
                 *[
                     (r, s, r.type.dtype_specs()[1])
-                    for r, s in izip(node.outputs, onames)
+                    for r, s in zip(node.outputs, onames)
                     if r not in dmap
                 ]
             )
@@ -968,7 +967,7 @@ second dimension
         # (output, name), transposed (c type name not needed since we don't
         # need to allocate.
         aliased = list(
-            zip(*[(r, s) for (r, s) in izip(node.outputs, onames) if r in dmap])
+            zip(*[(r, s) for (r, s) in zip(node.outputs, onames) if r in dmap])
         )
         if aliased:
             aliased_outputs, aliased_onames = aliased
@@ -986,7 +985,7 @@ second dimension
         # dimensionality)
         nnested = len(orders[0])
         sub = dict(sub)
-        for i, (input, iname) in enumerate(izip(inputs, inames)):
+        for i, (input, iname) in enumerate(zip(inputs, inames)):
             # the c generators will substitute the input names for
             # references to loop variables lv0, lv1, ...
             sub["lv%i" % i] = iname
@@ -1013,7 +1012,7 @@ second dimension
         # We loop over the "real" outputs, i.e., those that are not
         # inplace (must be allocated) and we declare/allocate/check
         # them
-        for output, oname, odtype in izip(real_outputs, real_onames, real_odtypes):
+        for output, oname, odtype in zip(real_outputs, real_onames, real_odtypes):
             i += 1  # before this loop, i = number of inputs
             sub["lv%i" % i] = oname
             sub["olv"] = oname
@@ -1030,7 +1029,7 @@ second dimension
         # inplace (overwrite the contents of one of the inputs) and
         # make the output pointers point to their corresponding input
         # pointers.
-        for output, oname in izip(aliased_outputs, aliased_onames):
+        for output, oname in zip(aliased_outputs, aliased_onames):
             olv_index = inputs.index(dmap[output][0])
             iname = inames[olv_index]
             # We make the output point to the corresponding input and
@@ -1097,7 +1096,7 @@ second dimension
                 task_decl = "".join(
                     [
                         "%s& %s_i = *%s_iter;\n" % (dtype, name, name)
-                        for name, dtype in izip(
+                        for name, dtype in zip(
                             inames + list(real_onames), idtypes + list(real_odtypes)
                         )
                     ]
@@ -1329,8 +1328,8 @@ class CAReduce(Op):
         - List of dimensions that we want to reduce
         - If None, all dimensions are reduced
 
-    Note
-    ----
+    Notes
+    -----
     .. code-block:: python
 
         CAReduce(add)      # sum (ie, acts like the numpy sum operation)
@@ -1557,13 +1556,13 @@ class CAReduce(Op):
             assert var.dtype == node.outputs[0].dtype
             return var.owner.op._c_all(var.owner, name, inames, onames, sub)
 
-        order1 = [i for i in xrange(input.type.ndim) if i not in axis]
+        order1 = [i for i in range(input.type.ndim) if i not in axis]
         order = order1 + list(axis)
 
         nnested = len(order1)
 
         sub = dict(sub)
-        for i, (input, iname) in enumerate(izip(node.inputs, inames)):
+        for i, (input, iname) in enumerate(zip(node.inputs, inames)):
             sub["lv%i" % i] = iname
 
         decl = ""
@@ -1756,12 +1755,13 @@ class CAReduce(Op):
 
 
 class All(CAReduce):
-    """ Applies `logical and` to all the values of a tensor along the
+    """Applies `logical and` to all the values of a tensor along the
     specified axis(es).
 
     """
 
     __props__ = ("axis",)
+    nfunc_spec = ("all", 1, 1)
 
     def __init__(self, axis=None):
         CAReduce.__init__(self, scalar.and_, axis)
@@ -1788,12 +1788,13 @@ class All(CAReduce):
 
 
 class Any(CAReduce):
-    """ Applies `bitwise or` to all the values of a tensor along the
+    """Applies `bitwise or` to all the values of a tensor along the
     specified axis(es).
 
     """
 
     __props__ = ("axis",)
+    nfunc_spec = ("any", 1, 1)
 
     def __init__(self, axis=None):
         CAReduce.__init__(self, scalar.or_, axis)
@@ -2028,6 +2029,7 @@ class Sum(CAReduceDtype):
     """
 
     __props__ = ("axis", "dtype", "acc_dtype")
+    nfunc_spec = ("sum", 1, 1)
 
     def __init__(self, axis=None, dtype=None, acc_dtype=None):
         CAReduceDtype.__init__(
@@ -2086,6 +2088,7 @@ class Prod(CAReduceDtype):
     """
 
     __props__ = ("axis", "dtype", "acc_dtype")
+    nfunc_spec = ("sum", 1, 1)
 
     def __init__(self, axis=None, dtype=None, acc_dtype=None, no_zeros_in_input=False):
         CAReduceDtype.__init__(
