@@ -13,7 +13,6 @@ import numpy as np
 
 import theano
 from theano import config, gof, printing, scalar
-from theano.compat import imap
 from theano.printing import pprint
 from theano.tensor import basic as tensor
 from theano.tensor import elemwise, opt, NotScalarConstantError
@@ -32,6 +31,8 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
 
     """
 
+    nfunc_spec = ("scipy.special.expit", 1, 1)
+
     @staticmethod
     def st_impl(x):
         if x < -30.0:
@@ -69,7 +70,7 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
         #
         # import numpy, theano
         # dt='float32'  # or float64
-        # for i in xrange(750):
+        # for i in range(750):
         #     print i, repr(theano._asarray(1.0, dtype=dt) /
         #                   (theano._asarray(1.0, dtype=dt) +
         #                    numpy.exp(-theano._asarray([i,-i], dtype=dt))))
@@ -81,15 +82,9 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
             node.inputs[0].type == scalar.float32
             or node.inputs[0].type == scalar.float16
         ):
-            return (
-                """%(z)s = %(x)s < -88.0f ? 0.0 : %(x)s > 15.0f ? 1.0f : 1.0f /(1.0f + exp(-%(x)s));"""
-                % locals()
-            )
+            return """%(z)s = 1.0f / (1.0f + exp(-%(x)s));""" % locals()
         elif node.inputs[0].type == scalar.float64:
-            return (
-                """%(z)s = %(x)s < -709.0 ? 0.0 : %(x)s > 19.0 ? 1.0 : 1.0 /(1.0+exp(-%(x)s));"""
-                % locals()
-            )
+            return """%(z)s = 1.0 / (1.0 + exp(-%(x)s));""" % locals()
         else:
             raise NotImplementedError("only floatingpoint is implemented")
 
@@ -203,6 +198,8 @@ class UltraFastScalarSigmoid(scalar.UnaryScalarOp):
 
     """
 
+    nfunc_spec = ("scipy.special.expit", 1, 1)
+
     @staticmethod
     def st_impl(x):
         x = 0.5 * x
@@ -380,7 +377,7 @@ class ScalarSoftplus(scalar.UnaryScalarOp):
         (z,) = out
         # These constants were obtained by looking at the output of
         # python commands like:
-        #  for i in xrange(750):
+        #  for i in range(750):
         #      print i, repr(numpy.log1p(numpy.exp(theano._asarray([i,-i], dtype=dt))))
         # the boundary checks prevent us from generating inf
 
@@ -791,7 +788,7 @@ def simplify_mul(tree):
     if isinstance(inputs, list):
         # Recurse through inputs.
         s_inputs = []
-        for s_i in imap(simplify_mul, inputs):
+        for s_i in map(simplify_mul, inputs):
             if s_i[1] is None:
                 # Multiplication by +/-1.
                 neg ^= s_i[0]
